wsql_sdk package — WSQL-SDK 0.2.1 documentation

# wsql_sdk package

## Subpackages

- wsql_sdk.syntax package
  - Submodules
  - wsql_sdk.syntax.asio module
  - wsql_sdk.syntax.pyaio module
  - wsql_sdk.syntax.pynative module
  - Module contents

## Submodules

## wsql_sdk.codegen module

This file is part of WSQL-SDK

The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED “AS IS”, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

class `wsql_sdk.codegen.` `Argument`(argument)

  Bases: `object`

  The procedure argument description

class `wsql_sdk.codegen.` `Builder`(syntax)

  Bases: `object`

  `create_api_output`(path, module)

    open new file to write procedures

  `create_exceptions_output`(path)

    open a new file to write exceptions

  static `validate`(procedure)

    validate procedure description

  `write`(text, eol='\n')

    write text to output stream

  `write_doc_string`(procedure)

    write doc string

  `write_exception`(exception)

    write the exception class

  `write_procedure`(procedure)

    handle the procedure body

  `write_returns`(returns, mod)

    return formatted return value

class `wsql_sdk.codegen.` `Procedure`(module, name, proc, read_only, errors)

  Bases: `object`

  The procedure description

  `fullname`

class `wsql_sdk.codegen.` `TempTable`(temptable)

  Bases: `object`

  The temporary table description

`wsql_sdk.codegen.` `create_builder`(name)

  load builder by syntax

`wsql_sdk.codegen.` `load_input`(source)

  load the input

`wsql_sdk.codegen.` `main`(argv=None)

`wsql_sdk.codegen.` `parse_arguments`(argv=None)

`wsql_sdk.codegen.` `process`(args)

  generate code according to specified parameters

## wsql_sdk.translator module

This file is part of WSQL-SDK

The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED “AS IS”, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

class `wsql_sdk.translator.` `Translator`(output, close_output=False)

  Bases: `wsql_sdk._interpreter.MacrosTokenizer`

  `compile`(filename)
  `include_file`(filename)
  `nop`(text)
  `on_function`(ast, body, args)
  `on_include`(filename)
  `on_variable`(name, value)

`wsql_sdk.translator.` `main`(argv=None)

`wsql_sdk.translator.` `parse_arguments`(argv=None)

## Module contents

This file is part of WSQL-SDK

The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED “AS IS”, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.